#!/usr/bin/env python
import sys
from os.path import basename, exists
import shelve
import json
from jsonpickle.pickler import Pickler


def main(argv):
    if len(argv) != 2:
        print('error: usage: {} [shelvefile]'.format(basename(argv[0])))
        return 1

    if not exists(sys.argv[1]):
        print('error: file does not exist: {}'.format(sys.argv[1]))
        return 2

    shelf = shelve.open(sys.argv[1])
    print(json.dumps(Pickler().flatten(dict(shelf)), indent=2))


def run():
    sys.exit(main(sys.argv) or 0)


if __name__ == '__main__':
    run()


#!/usr/bin/env python
# coding: utf-8

from setuptools import setup


setup(
    name='shelvedump',
    url='https://github.com/miracle2k/shelvedump',
    version='1.0',
    license='BSD',
    author=u'Michael Elsdörfer',
    author_email='michael@elsdoerfer.com',
    description=
        'dump the content of a Python shelve database to JSON',
    py_modules=['shelvedump'],
    install_requires=['jsonpickle'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
    ],
    entry_points="""[console_scripts]\nshelvedump = shelvedump:run\n""",
)